@@ -8,7 +8,7 @@ class Combobox(SmartWidget, TtkCombobox):
       if isinstance(kw["values"], dict):
          values = kw["values"]
          
-         kw["values"] = list(map(lambda i: self.__class__.formatValueString(values["text"], i, values.get("offset", 0)), range(values["count"])))
+         kw["values"] = list(map(lambda i: self.__class__.formatValueString(values.get("text", ""), i, values.get("offset", 0)), range(values["count"])))
       
       if "value" not in kw:
          kw["value"] = kw["values"][0]
@@ -19,12 +19,12 @@ class Combobox(SmartWidget, TtkCombobox):
       
       self._initValueAndTraceAdd()
    
+   def getValueIndex(self):
+      return self["values"].index(self.getValue())
+   
    @staticmethod
    def formatValueString(text, i, offset):
       return f"{text}{i + offset}"
-   
-   def getValueIndex(self):
-      return self["values"].index(self.getValue())
 
 
 class CommonCombobox(Combobox):
